<?php

    /**
     * Theme Options Config
     */

    if ( ! class_exists( 'WPCharming_Options_Config' ) ) {

        class WPCharming_Options_Config {

            public $args = array();
            public $sections = array();
            public $theme;
            public $ReduxFramework;

            public function __construct() {

                if ( ! class_exists( 'ReduxFramework' ) ) {
                    return;
                }

                // This is needed. Bah WordPress bugs.  ;)
                if ( true == Redux_Helpers::isTheme( __FILE__ ) ) {
                    $this->initSettings();
                } else {
                    add_action( 'plugins_loaded', array( $this, 'initSettings' ), 10 );
                }

            }

            public function initSettings() {

                // Set the default arguments
                $this->setArguments();

                // Set a few help tabs so you can see how it's done
                $this->setHelpTabs();

                // Create the sections and fields
                $this->setSections();

                if ( ! isset( $this->args['opt_name'] ) ) { // No errors please
                    return;
                }

                $this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
            }

            public function setHelpTabs() {

                // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
                $this->args['help_tabs'][] = array(
                    'id'      => 'redux-help-tab-1',
                    'title'   => __( 'Theme Information 1', 'wpcharming' ),
                    'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'wpcharming' )
                );

                $this->args['help_tabs'][] = array(
                    'id'      => 'redux-help-tab-2',
                    'title'   => __( 'Theme Information 2', 'wpcharming' ),
                    'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'wpcharming' )
                );

                // Set the help sidebar
                $this->args['help_sidebar'] = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'wpcharming' );
            }

            /**
             * All the possible arguments for Redux.
             * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
             * */
            public function setArguments() {

                $theme = wp_get_theme(); // For use with some settings. Not necessary.

                $this->args = array(
                    // TYPICAL -> Change these values as you need/desire
                    'opt_name'           => 'wpc_options',
                    // This is where your data is stored in the database and also becomes your global variable name.
                    'display_name'       => $theme->get( 'Name' ),
                    // Name that appears at the top of your panel
                    'display_version'    => $theme->get( 'Version' ),
                    // Version that appears at the top of your panel
                    'menu_type'          => 'menu',
                    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                    'allow_sub_menu'     => true,
                    // Show the sections below the admin menu item or not
                    'menu_title'         => __( 'Theme Options', 'wpcharming' ),
                    'page_title'         => __( 'Theme Options', 'wpcharming' ),
                    // You will need to generate a Google API key to use this feature.
                    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                    'google_api_key'     => '',
                    // Must be defined to add google fonts to the typography module

                    'async_typography'   => false,
                    // Use a asynchronous font on the front end or font string
                    'admin_bar'          => true,
                    // Show the panel pages on the admin bar
                    'global_variable'    => 'wpc_option',
                    // Set a different name for your global variable other than the opt_name
                    'dev_mode'           => false,
                    // Show the time the page took to load, etc
                    'customizer'         => false,
                    // Enable basic customizer support

                    // OPTIONAL -> Give you extra features
                    'page_priority'      => null,
                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                    'page_parent'        => 'themes.php',
                    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                    'page_permissions'   => 'manage_options',
                    // Permissions needed to access the options panel.
                    'menu_icon'          => '',
                    // Specify a custom URL to an icon
                    'last_tab'           => '',
                    // Force your panel to always open to a specific tab (by id)
                    'page_icon'          => 'icon-themes',
                    // Icon displayed in the admin panel next to your menu_title
                    'page_slug'          => 'wpcharming_options',
                    // Page slug used to denote the panel
                    'save_defaults'      => true,
                    // On load save the defaults to DB before user clicks save or not
                    'default_show'       => false,
                    // If true, shows the default value next to each field that is not the default value.
                    'default_mark'       => '',
                    // What to print by the field's title if the value shown is default. Suggested: *
                    'show_import_export' => true,
                    // Shows the Import/Export panel when not used as a field.

                    // CAREFUL -> These options are for advanced use only
                    'transient_time'     => 60 * MINUTE_IN_SECONDS,
                    'output'             => true,
                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                    'output_tag'         => true,
                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                    'footer_credit'     => ' ',                   
                    // Disable the footer credit of Redux. Please leave if you can help it.

                    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                    'database'           => '',
                    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                    'system_info'        => false,
                    // REMOVE

                    // HINTS
                    'hints'              => array(
                        'icon'          => 'icon-question-sign',
                        'icon_position' => 'right',
                        'icon_color'    => 'lightgray',
                        'icon_size'     => 'normal',
                        'tip_style'     => array(
                            'color'   => 'light',
                            'shadow'  => true,
                            'rounded' => false,
                            'style'   => '',
                        ),
                        'tip_position'  => array(
                            'my' => 'top left',
                            'at' => 'bottom right',
                        ),
                        'tip_effect'    => array(
                            'show' => array(
                                'effect'   => 'slide',
                                'duration' => '500',
                                'event'    => 'mouseover',
                            ),
                            'hide' => array(
                                'effect'   => 'slide',
                                'duration' => '500',
                                'event'    => 'click mouseleave',
                            ),
                        ),
                    )
                );


                // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
                /*
                $this->args['share_icons'][] = array(
                    'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
                    'title' => 'Visit us on GitHub',
                    'icon'  => 'el-icon-github'
                    //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
                );
                $this->args['share_icons'][] = array(
                    'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
                    'title' => 'Like us on Facebook',
                    'icon'  => 'el-icon-facebook'
                );
                $this->args['share_icons'][] = array(
                    'url'   => 'http://twitter.com/reduxframework',
                    'title' => 'Follow us on Twitter',
                    'icon'  => 'el-icon-twitter'
                );
                $this->args['share_icons'][] = array(
                    'url'   => 'http://www.linkedin.com/company/redux-framework',
                    'title' => 'Find us on LinkedIn',
                    'icon'  => 'el-icon-linkedin'
                );
                */

                // Panel Intro text -> before the form
                if ( ! isset( $this->args['global_variable'] ) || $this->args['global_variable'] !== false ) {
                    if ( ! empty( $this->args['global_variable'] ) ) {
                        $v = $this->args['global_variable'];
                    } else {
                        $v = str_replace( '-', '_', $this->args['opt_name'] );
                    }
                    //$this->args['intro_text'] = sprintf( __( '<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'wpcharming' ), $v );
                } else {
                    //$this->args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'wpcharming' );
                }

                // Add content after the form.
                //$this->args['footer_text'] = __( '<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'wpcharming' );
            }

            public function setSections() {


                /*--------------------------------------------------------*/
                /* GENERAL SETTINGS
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'General', 'wpcharming' ),
                    //'desc'   => sprintf( __( 'Redux Framework was created with the developer in mind. It allows for any theme developer to have an advanced theme panel with most of the features a developer would need. For more information check out the Github repo at: %d', 'wpcharming' ), '<a href="' . 'https://' . 'github.com/ReduxFramework/Redux-Framework">' . 'https://' . 'github.com/ReduxFramework/Redux-Framework</a>' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-cog el-icon-large',
                    'submenu' => true, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                    'fields' => array(

                        array(
                            'id'       =>'site_logo',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Site Logo', 'wpcharming'),
                            'default'  => array( 'url' => get_template_directory_uri() .'/assets/images/logo.png' ),
                            'subtitle' => __('Upload your logo here and enter the height of it below.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'site_logo_retina',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Site Logo Retina', 'wpcharming'),
                            'default'  => '',
                            'subtitle' => __('Upload at exactly 2x the size of your standard logo (optional), the name should include @2x at the end, example <strong>logo@2x.png</strong>', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'site_logo_margin_top',
                            'type'     => 'text',
                            'title'    => __('Logo Margin Top', 'wpcharming'),
                            'subtitle' => __('Your logo margin top in px. e.g. 20', 'wpcharming'),
                            'desc'     => "",
                            'default'  => '',
                        ),
                        array(
                            'id'       =>'site_favicon',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Site Favicon', 'wpcharming'),
                            'default'  => '',
                            'subtitle' => __('Upload a 16px x 16px .png or .gif image that will be your favicon.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'site_iphone_icon',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Apple iPhone Icon ', 'wpcharming'),
                            'default'  => '',
                            'subtitle' => __('Custom iPhone icon (57px x 57px).', 'wpcharming'),
                        ),
                        
                        array(
                            'id'       =>'site_iphone_icon_retina',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Apple iPhone Retina Icon ', 'wpcharming'),
                            'default'  => '',
                            'subtitle' => __('Custom iPhone retina icon (114px x 114px).', 'wpcharming'),
                        ),
                        
                        array(
                            'id'       =>'site_ipad_icon',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Apple iPad Icon ', 'wpcharming'),
                            'default'  => '',
                            'subtitle' => __('Custom iPad icon (72px x 72px).', 'wpcharming'),
                        ),
                        
                        array(
                            'id'       =>'site_ipad_icon_retina',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Apple iPad Retina Icon ', 'wpcharming'),
                            'default'  => '',
                            'subtitle' => __('Custom iPad retina icon (144px x 144px).', 'wpcharming'),
                        ),
                        array(
                            'id'       => 'page_comments',
                            'type'     => 'switch',
                            'title'    => __('Enable Page Comments?', 'wpcharming'),
                            'subtitle' => __('Do you want to enable comments on single page?', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       =>'site_footer_text',
                            'type'     => 'textarea',      
                            'title'    => __('Footer Text', 'wpcharming'), 
                            'subtitle' => __('Your footer copyright text.', 'wpcharming'),
                            'desc'     => "",
                            'default'  => ""
                        ),
                        array(
                            'id'       => 'enable_default_vc',
                            'type'     => 'switch',
                            'title'    => __('Turn ON default Visual Composer builder items?', 'wpcharming'),
                            'subtitle' => __('Do you want to enable all default Visual Composer builder items?', 'wpcharming'),
                            'default'  => false,
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* LAYOUTS
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Layout', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-website el-icon-large',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       => 'site_boxed',
                            'type'     => 'switch',
                            'title'    => __('Boxed Version?', 'wpcharming'),
                            'subtitle' => __('Do you want to enable boxed layout?', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'boxed_bg',
                            'type'     => 'background',
                            'compiler' => true,
                            'output'   => array('.layout-boxed'),
                            'title'    => __('Body Background for boxed layout', 'wpcharming'),
                            'default'  => array(
                                'background-color' => '#CCCCCC',
                            ),
                            //'required' => array('site_boxed','=',true, ),
                            
                        ),


                        array(
                            'id'       => 'page_layout',
                            'type'     => 'button_set',
                            'title'    => __( 'Page Layout', 'wpcharming' ),
                            'subtitle' => __( 'Default page layout.', 'wpcharming' ),
                            'options'  => array(
                                'left-sidebar'  => 'Left Sidebar',
                                'no-sidebar'    => 'No Sidebar',
                                'right-sidebar' => 'Right Sidebar'
                            ),
                            'default'  => 'right-sidebar'
                        ),
                        array(
                            'id'       => 'archive_layout',
                            'type'     => 'button_set',
                            'title'    => __( 'Archive Layout', 'wpcharming' ),
                            'subtitle' => __( 'Default archive layout ( front page, category, tag, search, author, archive ).', 'wpcharming' ),
                            'options'  => array(
                                'left-sidebar'  => 'Left Sidebar',
                                'no-sidebar'    => 'No Sidebar',
                                'right-sidebar' => 'Right Sidebar'
                            ),
                            'default'  => 'right-sidebar'
                        ),
                        array(
                            'id'       => 'blog_layout',
                            'type'     => 'button_set',
                            'title'    => __( 'Blog Layout', 'wpcharming' ),
                            'subtitle' => __( 'Set your blog layout to display, include blog page and single blog post.', 'wpcharming' ),
                            'options'  => array(
                                'left-sidebar'  => 'Left Sidebar',
                                'no-sidebar'    => 'No Sidebar',
                                'right-sidebar' => 'Right Sidebar'
                            ),
                            'default'  => 'right-sidebar'
                        ),
                        array(
                            'id'       => 'single_shop_layout',
                            'type'     => 'button_set',
                            'title'    => __( 'Single WooCommerce Product Layout', 'wpcharming' ),
                            'subtitle' => __( 'Layout for single product and products archive.', 'wpcharming' ),
                            'options'  => array(
                                'left-sidebar'  => 'Left Sidebar',
                                'no-sidebar'    => 'No Sidebar',
                                'right-sidebar' => 'Right Sidebar'
                            ),
                            'default'  => 'right-sidebar'
                        ),
                        array(
                            'id'       => 'woo_single_header',
                            'type'     => 'switch',
                            'title'    => __('Enable Single WooCommerce Page Header', 'wpcharming'),
                            'desc'     => __('Single product will use page header from SHOP page if you enable this option.', 'wpcharming'),
                            'default'  => true,
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* STYLING
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Styling', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-tint',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       => 'primary_color',
                            'type'     => 'color',
                            'title'    => __('Primary Color Schema', 'wpcharming'),
                            'default'  => '#bf9553'
                        ),
                        array(
                            'id'       => 'body_bg',
                            'type'     => 'background',
                            'compiler' => true,
                            'output'   => array('.site, .restaurant-menu-item .menu-desc span, .restaurant-menu-item .menu-price, .menu-heading-wrap h2.border_same_line span, .footer-connect'),
                            'title'    => __('Site Background', 'wpcharming'),
                            'default'  => array(
                            )
                            
                        ),
                        
                    )
                );


                /*--------------------------------------------------------*/
                /* TYPOGRAPHY
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'      => __('Typography', 'wpcharming'),
                    'header'     => '',
                    'desc'       => '',
                    'icon_class' => 'el-icon-large',
                    'icon'       => 'el-icon-font',
                    'submenu'    => true,
                    'fields'     => array(
                        array(
                            'id'             =>'font_body',
                            'type'           => 'typography', 
                            'title'          => __('Body', 'wpcharming'),
                            'compiler'       =>true,
                            'google'         =>true,
                            'font-backup'    =>false,
                            'font-weight'    =>false,
                            'all_styles'     =>true,
                            'font-style'     =>false,
                            'subsets'        =>true,
                            'font-size'      =>true,
                            'line-height'    =>false,
                            'word-spacing'   =>false,
                            'letter-spacing' =>false,
                            'color'          =>true,
                            'preview'        =>true,
                            'output'         => array('body'),
                            'units'          =>'px',
                            'subtitle'       => __('Select custom font for your main body text.', 'wpcharming'),
                            'default'        => array(
                                'color'       =>"#222222",
                                'font-family' =>'Open Sans', 
                                'font-size'   =>'15px',
                            )
                        ),
                        array(
                            'id'             =>'font_heading',
                            'type'           => 'typography', 
                            'title'          => __('Heading', 'wpcharming'),
                            'compiler'       =>true,
                            'google'         =>true,
                            'font-backup'    =>false,
                            'all_styles'     =>true,
                            'font-weight'    =>false,
                            'font-style'     =>false,
                            'subsets'        =>true,
                            'font-size'      =>false,
                            'line-height'    =>false,
                            'word-spacing'   =>false,
                            'letter-spacing' =>true,
                            'color'          =>true,
                            'preview'        =>true,
                            'output'         => array('h1,h2,h3,h4,h5,h6, .special-heading-2'),
                            'units'          =>'px',
                            'subtitle'       => __('Select custom font for heading like h1, h2, h3, ...', 'wpcharming'),
                            'default'        => array(
                                'color'       =>"#222222",
                                'font-family' =>'Lato',
                            )
                        ),
                        
                        array(
                            'id'             =>'special_heading_typography',
                            'type'           => 'typography', 
                            'title'          => __('Custom Heading', 'wpcharming'),
                            'compiler'       =>true,
                            'google'         =>true,
                            'font-backup'    =>false,
                            'font-weight'    =>true,
                            'all_styles'     =>false,
                            'font-style'     =>true,
                            'subsets'        =>true,
                            'font-size'      =>true,
                            'text-transform' =>true,
                            'line-height'    =>true,
                            'word-spacing'   =>false,
                            'letter-spacing' =>true,
                            'color'          =>true,
                            'preview'        =>true,
                            'output'         => array('.special-heading-1'),
                            'units'          =>'px',
                            'subtitle'       => __('Select custom style for <strong>Special Heading</strong> builder item.', 'wpcharming'),
                            'default'        => array(
                                'font-size'   => '70px',
                                'line-height' => '70px',
                                'font-family' =>'Aguafina Script',
                            )
                        ),
                        
                    ),
                );

                /*--------------------------------------------------------*/
                /* HEADER
                /*--------------------------------------------------------*/

                $this->sections[] = array(
                    'title'  => __( 'Header', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-file',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       => 'topbar_custom_color',
                            'type'     => 'switch',
                            'title'    => __('Custom Top Bar style?.', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'topbar_bg',
                            'type'     => 'background',
                            'title'    => __('Top Bar Background Color', 'wpcharming'),
                            'required' => array('topbar_custom_color','=',true, ),
                            'default'  => array(
                                'background-color' => '#000000',
                            )
                            
                        ),
                        array(
                            'id'       => 'topbar_text_color',
                            'type'     => 'color',
                            'title'    => __('Top Bar Text Color', 'wpcharming'),
                            'default'  => '#777777',
                            'required' => array('topbar_custom_color','=',true, )
                        ),
                        array(
                            'id'       => 'topbar_link_color',
                            'type'     => 'color',
                            'title'    => __('Top Bar Link Color', 'wpcharming'),
                            'default'  => '#999999',
                            'required' => array('topbar_custom_color','=',true, )
                        ),
                        array(
                            'id'       => 'topbar_link_color_hover',
                            'type'     => 'color',
                            'title'    => __('Top Bar Link Color Hover', 'wpcharming'),
                            'default'  => '#ffffff',
                            'required' => array('topbar_custom_color','=',true, )
                        ),
                        array(
                            'id'   =>'divider_1',
                            'desc' => '',
                            'type' => 'divide',
                            'required' => array('topbar_custom_color','=',true, )
                        ),
                        
                        array(
                            'id'       => 'header_fixed',
                            'type'     => 'switch',
                            'title'    => __('Enable fixed header on scroll.', 'wpcharming'),
                            'default'  => true,
                        ),

                        array(
                            'id'       => 'header_custom_style',
                            'type'     => 'switch',
                            'title'    => __('Custom Header Style?.', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'header_bg',
                            'type'     => 'background',
                            'title'    => __('Header Background', 'wpcharming'),
                            'required' => array('header_custom_style','=',true, ),
                            'default'  => array(
                                'background-color' => '#FFFFFF',
                            )
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* HEADER
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Primary Menu', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-credit-card',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'             =>'primary_menu_typography',
                            'type'           => 'typography', 
                            'title'          => __('Primary Menu Typography', 'wpcharming'),
                            'compiler'       =>true,
                            'google'         =>true,
                            'font-backup'    =>false,
                            'text-align'     =>false,
                            'text-transform' =>true,
                            'font-weight'    =>true,
                            'all_styles'     =>false,
                            'font-style'     =>true,
                            'subsets'        =>true,
                            'font-size'      =>true,
                            'line-height'    =>false,
                            'word-spacing'   =>false,
                            'letter-spacing' =>true,
                            'color'          =>true,
                            'preview'        =>true,
                            'output'         => array('#site-navigation .nav-menu li a, #site-navigation .menu li a, .onepage-navigation #site-navigation .nav-menu li.current-menu-item a, .onepage-navigation .menu li.current-menu-item a'),
                            'units'          =>'px',
                            'subtitle'       => __('Custom typography for primary menu.', 'wpcharming'),
                            'default'        => array(
                            )
                        ),
                        array(
                            'id'                =>'primary_dropdown_menu',
                            'type'              => 'typography', 
                            'title'             => __('Primary Dropdown Menu', 'wpcharming'),
                            'compiler'          =>true,
                            'font-family'       =>false,
                            'google'            =>false,
                            'font-backup'       =>false,
                            'text-align'        =>true,
                            'text-transform'    =>true,
                            'font-weight'       =>true,
                            'all_styles'        =>false,
                            'font-style'        =>true,
                            'subsets'           =>false,
                            'font-size'         =>true,
                            'line-height'       =>false,
                            'word-spacing'      =>false,
                            'letter-spacing'    =>true,
                            'color'             =>true,
                            'preview'           =>false,
                            'font_family_clear' =>true,
                            'output'            => array('#site-navigation .nav-menu .sub-menu li a, #site-navigation .menu .sub-menu li a'),
                            'units'             =>'px',
                            'subtitle'          => __('Custom setting for primary dropdown menu', 'wpcharming'),
                            'default'           => array(
                                
                            )
                        ),
                        array(
                            'id'       => 'primary_hide_arrow',
                            'type'     => 'switch',
                            'title'    => __('Hide submenu arrow?.', 'wpcharming'),
                            'default'  => false,
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* BLOG SETTINGS
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Blog', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-pencil el-icon-pencil',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       => 'blog_header',
                            'type'     => 'switch',
                            'title'    => __('Enable Blog Page Header', 'wpcharming'),
                            'subtitle' => __('Do you want to enable blog page header?', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'blog_single_header',
                            'type'     => 'switch',
                            'title'    => __('Enable Blog Page Header For Single Blog Post', 'wpcharming'),
                            'subtitle' => __('Do you want to enable blog page header on single blog post?', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       =>'blog_header_title',
                            'type'     => 'textarea',
                            'title'    => __('Blog Page Header Title', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => "",
                            'default'  => '',
                        ),
                        array(
                            'id'       =>'blog_header_subtitle',
                            'type'     => 'text',
                            'title'    => __('Blog Page Header Subtitle', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => "",
                            'default'  => '',
                        ),
                        array(
                            'id'      => 'blog_header_text_align',
                            'type'    => 'button_set',
                            'title'   => __( 'Text Alignment', 'wpcharming' ),
                            'desc'    => __( 'Choose how you would like your blog page header text to be aligned', 'wpcharming' ),
                            'type'    => 'button_set',
                            'default' => 'left',
                            'options' => array(
                                'left'   => __( 'Left', 'wpcharming' ),
                                'center' => __( 'Center', 'wpcharming' ),
                                'right'  => __( 'Right', 'wpcharming' ),
                            ),
                        ),
                        array(
                            'id'       =>'blog_header_bg_img',
                            'url'      => false,
                            'type'     => 'media', 
                            'title'    => __('Blog Page Header Image', 'wpcharming'),
                            'default'  => '',
                            'desc'     => __('The image should be between 1500px - 2000px wide and have a minimum height of 500px for best results.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'blog_header_padding_top',
                            'type'     => 'text',
                            'title'    => __('Padding Top', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __(' Your blog page header padding top in px. ee.g. 200, default is 120 ', 'wpcharming'),
                            'default'  => '120',
                        ),
                        array(
                            'id'       =>'blog_header_padding_bottom',
                            'type'     => 'text',
                            'title'    => __('Padding Bottom', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __(' Your blog page header padding bottom in px. ee.g. 200, default is 120 ', 'wpcharming'),
                            'default'  => '120',
                        ),
                        array(
                            'id'       => 'blog_header_parallax',
                            'type'     => 'switch',
                            'title'    => __('Parallax Blog Header?', 'wpcharming'),
                            'desc'     => __('Enable this option to have a parallax scroll effect. ', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'blog_header_bg',
                            'type'     => 'color',
                            'title'    => __('Blog Header Background Color', 'wpcharming'),
                            'desc'     => __('Set header background color if not using background image.', 'wpcharming'),
                            'default'  => '#444444',
                        ),
                        array(
                            'id'       => 'blog_header_text_color',
                            'type'     => 'color',
                            'title'    => __('Blog Header Text Color', 'wpcharming'),
                            'desc'     => __('Set blog header text color.', 'wpcharming'),
                            'default'  => '#FFFFFF',
                        ),
                        array(
                            'id'   =>'divider_1',
                            'desc' => '',
                            'type' => 'divide'
                        ),
                        array(
                            'id'       => 'blog_single_thumb',
                            'type'     => 'switch',
                            'title'    => __('Show Featured Image', 'wpcharming'),
                            'desc'     => __('Show featured image on single blog post?', 'wpcharming'),
                            'default'  => true,
                        ),
                        array(
                            'id'       => 'blog_single_share',
                            'type'     => 'switch',
                            'title'    => __('Show social share section', 'wpcharming'),
                            'desc'     => __('Show social share section on single blog post?', 'wpcharming'),
                            'default'  => true,
                        ),
                        array(
                            'id'       => 'blog_single_author',
                            'type'     => 'switch',
                            'title'    => __('Show Author Box', 'wpcharming'),
                            'desc'     => __('Show author bio box on single blog post?', 'wpcharming'),
                            'default'  => true,
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* EVENT SINGLE SETTINGS
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Event', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-calendar',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       => 'event_comments',
                            'type'     => 'switch',
                            'title'    => __('Enable Event Comments?', 'wpcharming'),
                            'subtitle' => __('Do you want to enable comments on single event?', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'single_event_page_header',
                            'type'     => 'switch',
                            'title'    => __('Show event page header', 'wpcharming'),
                            'desc'     => __('Do you want to show event page header on single event page? (You must select your event page from option below to make it work).', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'event_page',
                            'type'     => 'select',
                            'data'     => 'pages',
                            'title'    => __( 'Select your event page', 'wpcharming' ),
                            'desc'     => '',
                            'required' => array('single_event_page_header','=',true, )
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* FOOTER CONNECT
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Footer Connect', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-file-new',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       => 'footer_newsletter',
                            'type'     => 'switch',
                            'title'    => __('Enable footer Newsletter section', 'wpcharming'),
                            'desc'     => __('This section will display Newsletter form in footer top section.', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'newsletter_text',
                            'type'     => 'text',
                            'title'    => __('Newsletter Text', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter newsletter text before the form.', 'wpcharming'),
                            'default'  => 'Newsletter',
                        ),
                        array(
                            'id'       => 'newsletter_type',
                            'type'     => 'button_set',
                            'title'    => __( 'Newsletter Type', 'wpcharming' ),
                            'subtitle' => __( 'Select your newsletter type.', 'wpcharming' ),
                            'options'  => array(
                                'feedburner'  => 'FeedBurner',
                                'mailchimp'    => 'MailChimp'
                            )
                        ),
                        array(
                            'id'       => 'feedburner_id',
                            'type'     => 'text',
                            'title'    => __('Feedburner ID', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Feedburner ID.', 'wpcharming'),
                            'required' => array('newsletter_type','=','feedburner', )
                        ),
                        array(
                            'id'       => 'mailchimp_url',
                            'type'     => 'text',
                            'title'    => __('Mailchimp Action URL', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('You can get your MailChimp action URL by follow <a target="_blank" href="http://docs.shopify.com/manual/configuration/store-customization/communicating-with-customers/accounts-and-newsletters/where-do-i-get-my-mailchimp-form-action">this guide</a>.', 'wpcharming'),
                            'required' => array('newsletter_type','=','mailchimp', )
                        ),
                        array(
                            'id'   =>'divider_1',
                            'desc' => '',
                            'type' => 'divide'
                        ),
                        array(
                            'id'       => 'footer_social',
                            'type'     => 'switch',
                            'title'    => __('Enable footer connect social icon', 'wpcharming'),
                            'default'  => true,
                        ),
                        array(
                            'id'       => 'social_text',
                            'type'     => 'text',
                            'title'    => __('Social Text', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter social text before the social icons.', 'wpcharming'),
                            'default'  => 'Follow US',
                        ),
                        array(
                            'id'       => 'footer_use_social',
                            'type'     => 'checkbox',
                            'title'    => __('Enable Social Icon?', 'wpcharming'),
                            'subtitle' => __('Which icon should display? the social icon url will be take from Social Media setting tab.', 'wpcharming'),
                            'options'  => array(
                                'twitter'   => 'Twitter',
                                'facebook'  => 'Facebook',
                                'yelp'      => 'Yelp',
                                'pinterest' => 'Pinterest',
                                'google'    => 'Google',
                                'instagram' => 'Instagram',
                                'flickr'    => 'Flickr',
                                'youtube'   => 'Youtube',
                                'instagram' => 'Instagram',
                                'email'     => 'Email'
                            ),
                        ),

                    )
                );

                /*--------------------------------------------------------*/
                /* FOOTER
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Footer', 'wpcharming' ),
                    'desc'   => '',
                    'icon'   => 'el-icon-photo',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       => 'footer_widgets',
                            'type'     => 'switch',
                            'title'    => __('Enable footer widgets area.', 'wpcharming'),
                            'default'  => true,
                        ),
                        array(
                            'id'      => 'footer_columns',
                            'type'    => 'button_set',
                            'title'   => __( 'Footer Columns', 'wpcharming' ),
                            'desc'    => __( 'Select the number of columns you would like for your footer widgets area.', 'wpcharming' ),
                            'type'    => 'button_set',
                            'default' => '4',
                            'required' => array('footer_widgets','=',true, ),
                            'options' => array(
                                '1'   => __( '1 Columns', 'wpcharming' ),
                                '2'   => __( '2 Columns', 'wpcharming' ),
                                '3'   => __( '3 Columns', 'wpcharming' ),
                                '4'   => __( '4 Columns', 'wpcharming' ),
                            ),
                        ),
                        array(
                            'id'       =>'footer_copyright',
                            'type'     => 'textarea',
                            'title'    => __('Footer Copyright', 'wpcharming'),
                            'subtitle' => __('Enter the copyright section text.', 'wpcharming'),
                        ),
                        array(
                            'id'       => 'footer_custom_color',
                            'type'     => 'switch',
                            'title'    => __('Custom your footer style?.', 'wpcharming'),
                            'default'  => false,
                        ),
                        array(
                            'id'       => 'footer_bg',
                            'type'     => 'background',
                            'title'    => __('Footer Background', 'wpcharming'),
                            'required' => array('footer_custom_color','=',true, ),
                            'default'  => array(
                                'background-color' => '#000000',
                            )
                            
                        ),
                        array(
                            'id'       => 'footer_copy_border',
                            'type'     => 'color',
                            'title'    => __('Footer Copyright Border Top Color', 'wpcharming'),
                            'default'  => '',
                            'required' => array('footer_custom_color','=',true, )
                        ),
                        array(
                            'id'       => 'footer_widget_title_color',
                            'type'     => 'color',
                            'title'    => __('Footer Widget Title Color', 'wpcharming'),
                            'default'  => '#FFFFFF',
                            'required' => array('footer_custom_color','=',true, )
                        ),
                        array(
                            'id'       => 'footer_text_color',
                            'type'     => 'color',
                            'title'    => __('Footer Text Color', 'wpcharming'),
                            'default'  => '#666666',
                            'required' => array('footer_custom_color','=',true, )
                        ),
                        array(
                            'id'       => 'footer_link_color',
                            'type'     => 'color',
                            'title'    => __('Footer Link Color', 'wpcharming'),
                            'default'  => '#777777',
                            'required' => array('footer_custom_color','=',true, )
                        ),
                        array(
                            'id'       => 'footer_link_color_hover',
                            'type'     => 'color',
                            'title'    => __('Footer Link Color Hover', 'wpcharming'),
                            'default'  => '#ffffff',
                            'required' => array('footer_custom_color','=',true, )
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* SOCIAL
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'title'  => __( 'Social Media', 'wpcharming' ),
                    'desc'   => 'Enter social url here and then active them in footer or header options. Please add full URLs include "http://".',
                    'icon'   => 'el-icon-address-book',
                    'submenu' => true,
                    'fields' => array(
                        array(
                            'id'       =>'twitter',
                            'type'     => 'text',
                            'title'    => __('Twitter', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Twitter URL.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'facebook',
                            'type'     => 'text',
                            'title'    => __('Facebook', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Facebook URL.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'yelp',
                            'type'     => 'text',
                            'title'    => __('Yelp', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Yelp URL.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'pinterest',
                            'type'     => 'text',
                            'title'    => __('Pinterest', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Pinterest URL.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'google',
                            'type'     => 'text',
                            'title'    => __('Google Plus', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Google Plus URL.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'instagram',
                            'type'     => 'text',
                            'title'    => __('Instagram', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Instagram URL.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'flickr',
                            'type'     => 'text',
                            'title'    => __('Flickr', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Flickr URL.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'youtube',
                            'type'     => 'text',
                            'title'    => __('Youtube', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Youtube URL.', 'wpcharming'),
                        ),

                        array(
                            'id'       =>'email',
                            'type'     => 'text',
                            'title'    => __('Email', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter your Email URL.', 'wpcharming'),
                        ),
                        
                    )
                );

                /*--------------------------------------------------------*/
                /* TRACKING CODE
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'icon'       => 'el-icon-screenshot',
                    'icon_class' => 'el-icon-large',
                    'title'      => __('Tracking Codes', 'wpcharming'),
                    'submenu'    => true,
                    'fields'     => array(
                        array(
                            'id'       =>'site_header_tracking',
                            'type'     => 'textarea',
                            'theme'    => 'chrome',
                            'title'    => __('Header Tracking Codes', 'wpcharming'),
                            'subtitle' => __('It will apply to wp_head hook.', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'site_footer_tracking',
                            'type'     => 'textarea',
                            'theme'    => 'chrome',
                            'title'    => __('Footer Tracking Codes', 'wpcharming'),
                            'subtitle' => __('It will apply to wp_footer hook, recommend for Google Analytic (Remember to include the entire script from google, if you just enter your tracking ID it will not work.) ', 'wpcharming'),
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* CUSTOM CSS
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'icon'       => 'el-icon-css',
                    'icon_class' => 'el-icon-large',
                    'title'      => __('Custom CSS', 'wpcharming'),
                    'submenu'    => true,
                    'fields'     => array(
                        array(
                            'id'       => 'site_css',
                            'type'     => 'ace_editor',
                            'title'    => __( 'CSS Code', 'wpcharming' ),
                            'subtitle' => __( 'Paste your custom CSS code here.', 'wpcharming' ),
                            'mode'     => 'css',
                            'theme'    => 'monokai',
                            'desc'     => 'Possible modes can be found at <a href="'. esc_url( 'http://ace.c9.io' ) .'" target="_blank">'. esc_attr( 'http://ace.c9.io' ) .'</a>.',
                            'default'  => ""
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* AUTO UPDATE
                /*--------------------------------------------------------*/
                $this->sections[] = array(
                    'icon'       => 'el-icon-random',
                    'icon_class' => 'el-icon-large',
                    'title'      => __('One Click Update', 'wpcharming'),
                    'desc'    => __( 'Let us notify you when new versions of this theme are live on ThemeForest! Update with just one button click and forget about manual updates!<br> If you have any troubles while using auto update ( It is likely to be a permissions issue ) then you may want to manually update the theme as normal.', 'wpcharming' ),
                    'submenu'    => true,
                    'fields'     => array(
                        array(
                            'id'       =>'tf_username',
                            'type'     => 'text',
                            'title'    => __('ThemeForest Username', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter here your ThemeForest (or Envato) username account (i.e. WPCharming).', 'wpcharming'),
                        ),
                        array(
                            'id'       =>'tf_api',
                            'type'     => 'text',
                            'title'    => __('ThemeForest Secret API Key', 'wpcharming'),
                            'subtitle' => '',
                            'desc'     => __('Enter here the secret api key you have created on ThemeForest. You can create a new one in the Settings > API Keys section of your profile.', 'wpcharming'),
                        ),
                    )
                );

                /*--------------------------------------------------------*/
                /* 
                /*--------------------------------------------------------*/


            }

        }

        global $reduxConfig;
        $reduxConfig = new WPCharming_Options_Config();

        // Retrieve theme option values
        if ( ! function_exists('wpcharming_option') ) {
            function wpcharming_option($id, $fallback = false, $key = false ) {
                global $wpc_option;
                if ( $fallback == false ) $fallback = '';
                $output = ( isset($wpc_option[$id]) && $wpc_option[$id] !== '' ) ? $wpc_option[$id] : $fallback;
                if ( !empty($wpc_option[$id]) && $key ) {
                    $output = $wpc_option[$id][$key];
                }
                return $output;
            }
        }
    }
